@@ -236,7 +236,7 @@ class FormaPagamentoSelecaoResource(PagamentoConfiguracaoBaseResource):
 
     @property
     def valor(self):
-        return self.pagamento_configuracao.selecao.to_dict()
+        return self.pagamento_configuracao.selecao(self.dados).to_dict()
 
 
 #FIXME: ALERTA!!! ALERTA!!! SEM TESTES!!! ALERTA!!! ALERTA!!!
