@@ -61,7 +61,7 @@ class ValidadorBase(object):
 
 
 class CampoFormulario(object):
-    def __init__(self, nome, label, bound=True, descricao=None, requerido=False, tipo=TipoDeCampo.texto, formato=FormatoDeCampo.texto,
+    def __init__(self, nome, label, bound=True, descricao=None, requerido=False, tipo=TipoDeCampo.texto, formato=FormatoDeCampo.texto, invisivel=False,
                  tamanho_min=None, tamanho_max=None, ordem=0, texto_ajuda=None, opcoes=(), grupo=None, valor_padrao=None, validador=None, decimais=2):
         self.bound = bound
         self.ordem = ordem
@@ -71,6 +71,7 @@ class CampoFormulario(object):
         self.requerido = requerido
         self.tipo = tipo
         self.formato = formato
+        self.invisivel = invisivel
         self.tamanho_min = tamanho_min
         self.tamanho_max = tamanho_max
         self.texto_ajuda = texto_ajuda
@@ -89,6 +90,7 @@ class CampoFormulario(object):
             "descricao": self.descricao,
             "requerido": self.requerido,
             "tipo": self.tipo,
+            "invisivel": self.invisivel,
             "tamanho_min": self.tamanho_min,
             "tamanho_max": self.tamanho_max,
             "texto_ajuda": self.texto_ajuda,
