@@ -128,7 +128,7 @@ class RegistrarPagamento(Plugavel):
                 resultado = {"resultado": "erro", "mensagem": u"Nada foi registrado, pois os valores retornados não compõem um registro válido na LI."}
         if settings.GRAVA_EVIDENCIA:
             self.dados["tipo"] = self.tipo
-            tipo_evidencia = "pagador-retorno" if self.tipo == "retorno" else "pagador-redirect"
+            tipo_evidencia = "retorno" if self.tipo == "retorno" else "redirect"
             enviado = {"status_code": 200}
             enviado.update(resultado)
             grava_evidencia_retorno(self.meio_pagamento, self.dados, self.conta_id, self.registrador.pedido_numero, tipo_evidencia=tipo_evidencia, registrado=self.achou_registro, enviado=enviado)
