@@ -21,6 +21,10 @@ class Credenciador(object):
     def esta_valido(self):
         return True
 
+    @property
+    def suporta_atualizacao(self):
+        return False
+
     @property
     def chave(self):
         return "access_token"
@@ -57,7 +61,7 @@ class Credenciais(base.Plugavel):
     def define_autenticacao(self, url=None, atualiza_autenticacao=False):
         if not url:
             url = self.credenciador.url
-        if atualiza_autenticacao or not self.esta_valido():
+        if self.credenciador.suporta_atualizacao and (atualiza_autenticacao or not self.credenciador.esta_valido()):
             self.configuracao_pagamento.atualizar()
         if self.credenciador.tipo == TipoAutenticacao.cabecalho_http:
             return self.por_cabecalho_http()
@@ -68,9 +72,6 @@ class Credenciais(base.Plugavel):
             return "{}{}{}".format(url, separador, self.por_query_string())
         return None
 
-    def esta_valido(self):
-        return self.credenciador.esta_valido()
-
     def por_query_string(self):
         return "{}={}".format(self.credenciador.chave, self.credenciador.obter_credenciais())
 
